export declare class NgLocalStorage {
    private appName;
    private noSupportMessage;
    private objectProperties;
    private hasSublevel;
    private hasStorageSupport;
    /**
     * @constructor
     */
    constructor();
    /**
     * localStorage `getItem` method
     * @param {string} props - Dot separated string - dot notation to access property values
     */
    get(props: string): any;
    /**
     * localStorage `setItem` method
     * @param {string} key - Item / key where the value will be stored
     * @param {any} value - Value to be stored; Whether a String or an Object
     */
    set(key: string, value: any): void;
    /**
     * localStorage `remove` method
     * @param {string} key - Item key to be removed from localStorage
     */
    remove(key: string): void;
    /**
     * localStorage `clear` method
     */
    clear(): void;
    /**
     * Used to extract Object from giving dot-notation string
     * @param {string} props - Dot separated string - dot notation to access property values
     */
    private __extractObjectName(props);
    /**
     * Recursive method to get property value based on dot-notation string input
     * @param {object} obj - Object to be searched
     * @param {string} props - Dot separated string - dot notation to access property values
     */
    private __getPropertyData(obj, props);
    /**
     * Used to catch possible errors in parsing data
     * @param {any} data - Value retrieved from localStorage data
     */
    private __tryParse(data);
    /**
     * Used to check localStorage support
     */
    private __supportsLocalStorage();
}
